/***************************************************************************
 *   Copyright (C) 2007 by Felix H. Dahlke   *
 *   fhd@ubercode.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kconfig.h>

#include "kbcconfiguration.h"

KBCConfiguration::KBCConfiguration(KConfig *kconfig)
{
	this->kconfig = kconfig;

	loadFromConfigFile();
}


KBCConfiguration::~KBCConfiguration()
{}

void KBCConfiguration::loadFromConfigFile()
{
	loadDefaults();

	bit_shape = (kconfig->readEntry("BitShape") == "RECTANGULAR") ? RECTANGLE : ELLIPSE;

	borderColor0 = kconfig->readColorEntry("InactiveBorderColor", &borderColor0);
	fillColor0 = kconfig->readColorEntry("InactiveFillColor", &fillColor0);

	borderColor1 = kconfig->readColorEntry("ActiveBorderColor", &borderColor1);
	fillColor1 = kconfig->readColorEntry("ActiveFillColor", &fillColor1);

	hxstart = kconfig->readNumEntry("HourMargin", hxstart);
	hxgap = kconfig->readNumEntry("HourPadding", hxgap);
	hxsize = kconfig->readNumEntry("HourWidth", hxsize);
	hysize = kconfig->readNumEntry("HourHeight", hysize);

	mxstart = kconfig->readNumEntry("MinuteMargin", mxstart);
	mxgap = kconfig->readNumEntry("MinutePadding", mxgap);
	mxsize = kconfig->readNumEntry("MinuteWidth", mxsize);
	mysize = kconfig->readNumEntry("MinuteHeight", mysize);

	hystart = kconfig->readNumEntry("VertMargin", hystart);
	mystart = kconfig->readNumEntry("VertPadding", mystart);
}

void KBCConfiguration::writeToConfigFile()
{
	kconfig->writeEntry("BitShape", (bit_shape == RECTANGLE) ? "RECTANGULAR" : "ELLIPSOID");

	kconfig->writeEntry("InactiveBorderColor", borderColor0);
	kconfig->writeEntry("InactiveFillColor", fillColor0);

	kconfig->writeEntry("ActiveBorderColor", borderColor1);
	kconfig->writeEntry("ActiveFillColor", fillColor1);
	
	kconfig->writeEntry("HourMargin", hxstart);
	kconfig->writeEntry("HourPadding", hxgap);
	kconfig->writeEntry("HourWidth", hxsize);
	kconfig->writeEntry("HourHeight", hysize);

	kconfig->writeEntry("MinuteMargin", mxstart);
	kconfig->writeEntry("MinutePadding", mxgap);
	kconfig->writeEntry("MinuteWidth", mxsize);
	kconfig->writeEntry("MinuteHeight", mysize);

	kconfig->writeEntry("VertMargin", hystart);
	kconfig->writeEntry("VertPadding", mystart);

	kconfig->sync();
}

void KBCConfiguration::loadDefaults()
{
	bit_shape = ELLIPSE;

	borderColor0 = QColor(0, 0, 0);
	fillColor0 = QColor(125, 125, 125);
	borderColor1 = QColor(0, 0, 0);
	fillColor1 = QColor(0, 200, 0);

	hxstart = 15;
	hystart = 2;
	mxstart = 5;
	mystart = 15;
	hxgap = 7;
	mxgap = 5;
	hxsize = 10;
	hysize = 10;
	mxsize = 10;
	mysize = 10;
}
