/***************************************************************************
 *   Copyright (C) 2007 by Felix H. Dahlke   *
 *   fhd@ubercode.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qradiobutton.h>
#include <kcolorbutton.h>
#include <qspinbox.h>

#include "kbcconfiguration.h"
#include "kbcconfigwindow.h"

KBCConfigWindow::KBCConfigWindow(QWidget *parent, KBCConfiguration *config)
		: Form1(parent)
{
	this->config = config;
	showConfig();
}

void KBCConfigWindow::showConfig()
{
	if (config->bit_shape == ELLIPSE) {
		radioEllipsoid->setChecked(true);
		radioRectangular->setChecked(false);
	} else {
		radioRectangular->setChecked(true);
		radioEllipsoid->setChecked(false);
	}

	kColorInactiveBorder->setColor(config->borderColor0);
	kColorInactiveFill->setColor(config->fillColor0);
	kColorActiveBorder->setColor(config->borderColor1);
	kColorActiveFill->setColor(config->fillColor1);

	spinHourMargin->setValue(config->hxstart);
	spinHourPadding->setValue(config->hxgap);
	spinHourWidth->setValue(config->hxsize);
	spinHourHeight->setValue(config->hysize);

	spinMinuteMargin->setValue(config->mxstart);
	spinMinutePadding->setValue(config->mxgap);
	spinMinuteWidth->setValue(config->mxsize);
	spinMinuteHeight->setValue(config->mysize);

	spinVertMargin->setValue(config->hystart);
	spinVertPadding->setValue(config->mystart);
}

void KBCConfigWindow::updateConfig()
{
	config->bit_shape = (radioEllipsoid->isChecked()) ? ELLIPSE : RECTANGLE;

	config->borderColor0 = kColorInactiveBorder->color();
	config->fillColor0 = kColorInactiveFill->color();
	config->borderColor1 = kColorActiveBorder->color();
	config->fillColor1 = kColorActiveFill->color();

	config->hxstart = spinHourMargin->value();
	config->hxgap = spinHourPadding->value();
	config->hxsize = spinHourWidth->value();
	config->hysize = spinHourHeight->value();

	config->mxstart = spinMinuteMargin->value();
	config->mxgap = spinMinutePadding->value();
	config->mxsize = spinMinuteWidth->value();
	config->mysize = spinMinuteHeight->value();

	config->hystart = spinVertMargin->value();
	config->mystart = spinVertPadding->value();

	config->writeToConfigFile();

	emit configUpdated(config);
}

void KBCConfigWindow::onOK()
{
	updateConfig();
	close();
}

void KBCConfigWindow::onDefaults()
{
	config->loadDefaults();
	showConfig();
}

void KBCConfigWindow::onApply()
{
	updateConfig();
}



#include "kbcconfigwindow.moc"
